==> qtjambi-scxml-debuginfo-linux-x64-6.5.4.jar: sources/QtJambiScxml/QScxmlDataModel_ForeachLoopBody_shell.cpp <==
#include "QScxmlDataModel_ForeachLoopBody_shell.h"
#include <QtJambi/Cast>

void deleter_QScxmlDataModel_ForeachLoopBody(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QScxmlDataModel::ForeachLoopBody")
    QScxmlDataModel::ForeachLoopBody *_ptr = reinterpret_cast<QScxmlDataModel::ForeachLoopBody *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QScxmlDataModel$ForeachLoopBody_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QScxmlDataModel$ForeachLoopBody_shell) ); }

jmethodID QScxmlDataModel$ForeachLoopBody_shell::__shell_javaMethod(int pos) const { return QScxmlDataModel$ForeachLoopBody_shell::__shell()->javaMethod(typeid(QScxmlDataModel::ForeachLoopBody), pos); }

// emitting (writeShellConstructor)
QScxmlDataModel$ForeachLoopBody_shell::QScxmlDataModel$ForeachLoopBody_shell()
    : QScxmlDataModel::ForeachLoopBody()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QScxmlDataModel::ForeachLoopBody::QScxmlDataModel$ForeachLoopBody_shell()", QScxmlDataModel$ForeachLoopBody_shell::__shell())
    QScxmlDataModel$ForeachLoopBody_shell::__shell()->constructed(typeid(QScxmlDataModel::ForeachLoopBody));
}

// emitting (writeShellDestructor)
QScxmlDataModel$ForeachLoopBody_shell::~QScxmlDataModel$ForeachLoopBody_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QScxmlDataModel::ForeachLoopBody::~QScxmlDataModel::ForeachLoopBody()", QScxmlDataModel$ForeachLoopBody_shell::__shell())
    QScxmlDataModel$ForeachLoopBody_shell::__shell()->destructed(typeid(QScxmlDataModel::ForeachLoopBody));
}

void QScxmlDataModel$ForeachLoopBody_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QScxmlDataModel$ForeachLoopBody_shell*>(ptr)->QScxmlDataModel$ForeachLoopBody_shell::__shell()->tryDeleteShell(typeid(QScxmlDataModel::ForeachLoopBody));
}

// emitting Virtual overrides (virtualFunctions)
void QScxmlDataModel$ForeachLoopBody_shell::run(bool* ok0)
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QScxmlDataModel::ForeachLoopBody::", QScxmlDataModel$ForeachLoopBody_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QScxmlDataModel$ForeachLoopBody_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jboolean __java_return_value = __jni_env->CallBooleanMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    if(ok0){
                        *ok0 = __java_return_value;
                    }
                } else {
                    QScxmlDataModel$ForeachLoopBody_shell::__shell()->warnForMethod("QScxmlDataModel::ForeachLoopBody::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QScxmlDataModel::ForeachLoopBody::");
            } QTJAMBI_TRY_END
        }
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jboolean QScxmlDataModel$ForeachLoopBody_access::__qt_run_bool_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    bool ok0 = false;
    bool* __qt_ok0 = &ok0;
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QScxmlDataModel::ForeachLoopBody::run(bool * ok)." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QScxmlDataModel::ForeachLoopBody::run(bool * ok).";
    } else {
        run(__qt_ok0);
        jboolean __java_return_value = ok0;
        return __java_return_value;
    }
}

// emitting (writeConstructors)
// new 
void __qt_construct_QScxmlDataModel_ForeachLoopBody_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QScxmlDataModel::ForeachLoopBody *__qt_this = new(__qtjambi_ptr) QScxmlDataModel$ForeachLoopBody_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QScxmlDataModel$ForeachLoopBody_shell
void __qt_destruct_QScxmlDataModel_ForeachLoopBody(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QScxmlDataModel::ForeachLoopBody")
    reinterpret_cast<QScxmlDataModel$ForeachLoopBody_shell*>(ptr)->~QScxmlDataModel$ForeachLoopBody_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QScxmlDataModel::ForeachLoopBody::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlDataModel_00024ForeachLoopBody_00024Impl_initialize_1native__Lio_qt_scxml_QScxmlDataModel_00024ForeachLoopBody_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QScxmlDataModel::ForeachLoopBody::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QScxmlDataModel_ForeachLoopBody_0, sizeof(QScxmlDataModel$ForeachLoopBody_shell), typeid(QScxmlDataModel::ForeachLoopBody), true, &deleter_QScxmlDataModel_ForeachLoopBody, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QScxmlDataModel::ForeachLoopBody::run(bool*)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlDataModel_00024ForeachLoopBody_00024Impl_00024ConcreteWrapper_run_1native_1bool_1ptr__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QScxmlDataModel::ForeachLoopBody *__qt_this = QtJambiAPI::interfaceFromNativeId<QScxmlDataModel::ForeachLoopBody>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScxmlDataModel::ForeachLoopBody::run(bool*)", __qt_this)
        __java_return_value = static_cast<QScxmlDataModel$ForeachLoopBody_access*>(__qt_this)->__qt_run_bool_ptr(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QScxmlDataModel_ForeachLoopBody(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QScxmlDataModel::ForeachLoopBody>("QScxmlDataModel::ForeachLoopBody", "io/qt/scxml/QScxmlDataModel$ForeachLoopBody");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "run", "()Z", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, &__qt_destruct_QScxmlDataModel_ForeachLoopBody, {
        ConstructorInfo(&__qt_construct_QScxmlDataModel_ForeachLoopBody_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QScxmlDataModel_ForeachLoopBody);
    registerSizeOfShell(typeId, sizeof(QScxmlDataModel$ForeachLoopBody_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QScxmlDataModel::ForeachLoopBody* _object = dynamic_cast<QScxmlDataModel::ForeachLoopBody*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QScxmlDataModel::ForeachLoopBody *object = reinterpret_cast<QScxmlDataModel::ForeachLoopBody *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QScxmlDataModel::ForeachLoopBody *object = reinterpret_cast<const QScxmlDataModel::ForeachLoopBody *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-scxml-debuginfo-linux-x64-6.6.3.jar: sources/QtJambiScxml/QScxmlDataModel_ForeachLoopBody_shell.cpp <==
#include "QScxmlDataModel_ForeachLoopBody_shell.h"
#include <QtJambi/Cast>

void deleter_QScxmlDataModel_ForeachLoopBody(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QScxmlDataModel::ForeachLoopBody")
    QScxmlDataModel::ForeachLoopBody *_ptr = reinterpret_cast<QScxmlDataModel::ForeachLoopBody *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QScxmlDataModel$ForeachLoopBody_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QScxmlDataModel$ForeachLoopBody_shell) ); }

jmethodID QScxmlDataModel$ForeachLoopBody_shell::__shell_javaMethod(int pos) const { return QScxmlDataModel$ForeachLoopBody_shell::__shell()->javaMethod(typeid(QScxmlDataModel::ForeachLoopBody), pos); }

// emitting (writeShellConstructor)
QScxmlDataModel$ForeachLoopBody_shell::QScxmlDataModel$ForeachLoopBody_shell()
    : QScxmlDataModel::ForeachLoopBody()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QScxmlDataModel::ForeachLoopBody::QScxmlDataModel$ForeachLoopBody_shell()", QScxmlDataModel$ForeachLoopBody_shell::__shell())
    QScxmlDataModel$ForeachLoopBody_shell::__shell()->constructed(typeid(QScxmlDataModel::ForeachLoopBody));
}

// emitting (writeShellDestructor)
QScxmlDataModel$ForeachLoopBody_shell::~QScxmlDataModel$ForeachLoopBody_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QScxmlDataModel::ForeachLoopBody::~QScxmlDataModel::ForeachLoopBody()", QScxmlDataModel$ForeachLoopBody_shell::__shell())
    QScxmlDataModel$ForeachLoopBody_shell::__shell()->destructed(typeid(QScxmlDataModel::ForeachLoopBody));
}

void QScxmlDataModel$ForeachLoopBody_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QScxmlDataModel$ForeachLoopBody_shell*>(ptr)->QScxmlDataModel$ForeachLoopBody_shell::__shell()->tryDeleteShell(typeid(QScxmlDataModel::ForeachLoopBody));
}

// emitting Virtual overrides (virtualFunctions)
void QScxmlDataModel$ForeachLoopBody_shell::run(bool* ok0)
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QScxmlDataModel::ForeachLoopBody::", QScxmlDataModel$ForeachLoopBody_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QScxmlDataModel$ForeachLoopBody_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jboolean __java_return_value = __jni_env->CallBooleanMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    if(ok0){
                        *ok0 = __java_return_value;
                    }
                } else {
                    QScxmlDataModel$ForeachLoopBody_shell::__shell()->warnForMethod("QScxmlDataModel::ForeachLoopBody::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QScxmlDataModel::ForeachLoopBody::");
            } QTJAMBI_TRY_END
        }
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jboolean QScxmlDataModel$ForeachLoopBody_access::__qt_run_bool_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    bool ok0 = false;
    bool* __qt_ok0 = &ok0;
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QScxmlDataModel::ForeachLoopBody::run(bool * ok)." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QScxmlDataModel::ForeachLoopBody::run(bool * ok).";
    } else {
        run(__qt_ok0);
        jboolean __java_return_value = ok0;
        return __java_return_value;
    }
}

// emitting (writeConstructors)
// new ForeachLoopBody()
void __qt_construct_QScxmlDataModel_ForeachLoopBody(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ForeachLoopBody()")
    Q_UNUSED(__java_arguments)
    QScxmlDataModel::ForeachLoopBody *__qt_this = new(__qtjambi_ptr) QScxmlDataModel$ForeachLoopBody_shell();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QScxmlDataModel::ForeachLoopBody::ForeachLoopBody()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlDataModel_00024ForeachLoopBody_00024Impl_initialize_1native__Lio_qt_scxml_QScxmlDataModel_00024ForeachLoopBody_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QScxmlDataModel::ForeachLoopBody::ForeachLoopBody()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QScxmlDataModel_ForeachLoopBody, sizeof(QScxmlDataModel$ForeachLoopBody_shell), typeid(QScxmlDataModel::ForeachLoopBody), true, &deleter_QScxmlDataModel_ForeachLoopBody, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QScxmlDataModel$ForeachLoopBody_shell
void __qt_destruct_QScxmlDataModel_ForeachLoopBody(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QScxmlDataModel::ForeachLoopBody")
    reinterpret_cast<QScxmlDataModel$ForeachLoopBody_shell*>(ptr)->~QScxmlDataModel$ForeachLoopBody_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QScxmlDataModel::ForeachLoopBody::run(bool*)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_scxml_QScxmlDataModel_00024ForeachLoopBody_00024Impl_00024ConcreteWrapper_run_1native_1bool_1ptr__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QScxmlDataModel::ForeachLoopBody *__qt_this = QtJambiAPI::interfaceFromNativeId<QScxmlDataModel::ForeachLoopBody>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScxmlDataModel::ForeachLoopBody::run(bool*)", __qt_this)
        __java_return_value = static_cast<QScxmlDataModel$ForeachLoopBody_access*>(__qt_this)->__qt_run_bool_ptr(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QScxmlDataModel_ForeachLoopBody(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QScxmlDataModel::ForeachLoopBody>("QScxmlDataModel::ForeachLoopBody", "io/qt/scxml/QScxmlDataModel$ForeachLoopBody");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "run", "()Z", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, &__qt_destruct_QScxmlDataModel_ForeachLoopBody, {
        ConstructorInfo(&__qt_construct_QScxmlDataModel_ForeachLoopBody, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QScxmlDataModel_ForeachLoopBody);
    registerSizeOfShell(typeId, sizeof(QScxmlDataModel$ForeachLoopBody_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QScxmlDataModel::ForeachLoopBody* _object = dynamic_cast<QScxmlDataModel::ForeachLoopBody*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QScxmlDataModel::ForeachLoopBody *object = reinterpret_cast<QScxmlDataModel::ForeachLoopBody *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QScxmlDataModel::ForeachLoopBody *object = reinterpret_cast<const QScxmlDataModel::ForeachLoopBody *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
